@@ -1,5 +1,6 @@
 #' @importFrom forcats fct_relevel
 #' @importFrom stringr str_sort str_detect
+#' @importFrom rlang ensym as_name
 #### assume RHS is a distribution
 #### if distribution, isolate distribution name,
 #### parameter names/values, and argument names/values
@@ -532,16 +533,21 @@ updateExtractArguments = function(graphWithDim) {
     dplyr::left_join(graph$arg_df, by = c("rhsID" = "rhsID","fromLabel" = "argValue")) %>%
     select(rhsID,argName,argType,argValue = fromLabel,argDimLabels = dimLabel)  ##new dim label
 
-  graph$arg_df = dplyr::bind_rows(graph$arg_df,rowsToAddtoArgDF) %>%
-    dplyr::mutate(argID = row_number()) %>%  ## retain order of arguments
-    dplyr::group_by(rhsID,argName,argType,argValue) %>%
-    dplyr::summarize(argDimLabels = paste0(argDimLabels, collapse = ","),
-                     minRowID = min(argID)) %>%
-    dplyr::mutate(argDimLabels = gsub("NA,","",argDimLabels)) %>%
-    dplyr::mutate(argDimLabels = ifelse(argDimLabels=="NA",as.character(NA),argDimLabels)) %>%
-    dplyr::arrange(rhsID,minRowID) %>%
-    dplyr::select(-minRowID) %>%
-    as.data.frame()
+  ## update if nrow >= 1
+  if (nrow(graph$arg_df) >= 1) {
+    graph$arg_df = dplyr::bind_rows(graph$arg_df, rowsToAddtoArgDF) %>%
+      dplyr::mutate(argID = row_number()) %>%  ## retain order of arguments
+      dplyr::group_by(rhsID, argName, argType, argValue) %>%
+      dplyr::summarize(
+        argDimLabels = paste0(argDimLabels, collapse = ","),
+        minRowID = min(argID)
+      ) %>%
+      dplyr::mutate(argDimLabels = gsub("NA,", "", argDimLabels)) %>%
+      dplyr::mutate(argDimLabels = ifelse(argDimLabels == "NA", as.character(NA), argDimLabels)) %>%
+      dplyr::arrange(rhsID, minRowID) %>%
+      dplyr::select(-minRowID) %>%
+      as.data.frame()
+  }
 
   return(graph)
 }
@@ -572,4 +578,45 @@ makeDiagMatrix = function(diagVec) {
     return(diagMatrix)
   }
 
+# below two functions allow one to get objectName
+# that becomes argument in meaningfulLabels()
+# when using dag_greta(mcmc=FALSE)
+# see https://michaelbarrowman.co.uk/post/getting-a-variable-name-in-a-pipeline/
+get_lhs <- function(){
+  calls <- sys.calls()
+
+  #pull out the function or operator (e.g. the `%>%`)
+  call_firsts <- lapply(calls,`[[`,1)
+
+  #check which ones are equal to the pipe
+  pipe_calls <- vapply(call_firsts,identical,logical(1),quote(`%>%`))
+
+  #if we have no pipes, then get_lhs() was called incorrectly
+  if(all(!pipe_calls)){
+    NULL
+  } else {
+    #Get the most recent pipe, lowest on the
+    pipe_calls <- which(pipe_calls)
+    pipe_calls <- pipe_calls[length(pipe_calls)]
+
+    #Get the second element of the pipe call
+    this_call <- calls[[c(pipe_calls,2)]]
+
+    #We need to dig down into the call to find the original
+    while(is.call(this_call) && identical(this_call[[1]],quote(`%>%`))){
+      this_call <- this_call[[2]]
+    }
+    this_call
+
+  }
+}
+# see https://michaelbarrowman.co.uk/post/getting-a-variable-name-in-a-pipeline/
+get_name <- function(x){
+    lhs <- get_lhs()
+    if(is.null(lhs)){
+      lhs <- rlang::ensym(x)
+    }
+    rlang::as_name(lhs)
+}
+
 
